@@ -3,11 +3,11 @@ from ai_traineree.agents.ddpg import DDPGAgent
 from ai_traineree.agents.dqn import DQNAgent
 from ai_traineree.agents.ppo import PPOAgent
 from ai_traineree.agents.rainbow import RainbowAgent
+from ai_traineree.agents.sac import SACAgent
 from ai_traineree.types import AgentState
 
 
 class AgentFactory:
-
     @staticmethod
     def from_state(state: AgentState) -> AgentBase:
         norm_model = state.model.upper()
@@ -19,5 +19,7 @@ class AgentFactory:
             return DDPGAgent.from_state(state)
         elif norm_model == RainbowAgent.model.upper():
             return RainbowAgent.from_state(state)
+        elif norm_model == SACAgent.model.upper():
+            return SACAgent.from_state(state)
         else:
             raise ValueError(f"Agent state contains unsupported model type: {state.model}")
