@@ -5,7 +5,7 @@
 
 import itertools
 from functools import cached_property
-from typing import Dict, List
+from typing import Dict
 
 import torch
 import torch.nn as nn
@@ -15,13 +15,14 @@ from torch.optim import Adam
 from ai_traineree import DEVICE
 from ai_traineree.agents import AgentBase
 from ai_traineree.agents.agent_utils import hard_update, soft_update
-from ai_traineree.buffers import NStepBuffer, PERBuffer
+from ai_traineree.buffers.nstep import NStepBuffer
+from ai_traineree.buffers.per import PERBuffer
 from ai_traineree.loggers import DataLogger
 from ai_traineree.networks.bodies import ActorBody, CriticBody
 from ai_traineree.networks.heads import CategoricalNet
 from ai_traineree.policies import MultivariateGaussianPolicy, MultivariateGaussianPolicySimple
 from ai_traineree.types.dataspace import DataSpace
-from ai_traineree.types.primitive import ActionType, DoneType, ObsType, RewardType
+from ai_traineree.types.experience import Experience
 from ai_traineree.utils import to_numbers_seq, to_tensor
 
 
@@ -48,7 +49,7 @@ class D4PGAgent(AgentBase):
             obs_space (DataSpace): Dataspace describing the input.
             action_space (DataSpace): Dataspace describing the output.
 
-        Keyword parameters:
+        Keyword arguments:
             hidden_layers (tuple of ints): Shape of the hidden layers in fully connected network. Default: (128, 128).
             gamma (float): Discount value. Default: 0.99.
             tau (float): Soft-copy factor. Default: 0.02.
@@ -75,61 +76,77 @@ class D4PGAgent(AgentBase):
         self.device = self._register_param(kwargs, "device", DEVICE)
         self.obs_space = obs_space
         self.action_space = action_space
-        self._config['obs_space'] = self.obs_space
-        self._config['action_space'] = self.action_space
+        self._config["obs_space"] = self.obs_space
+        self._config["action_space"] = self.action_space
         action_size = self.action_space.shape[0]
 
-        self.num_atoms = int(self._register_param(kwargs, 'num_atoms', 51))
-        v_min = float(self._register_param(kwargs, 'v_min', -10))
-        v_max = float(self._register_param(kwargs, 'v_max', 10))
+        self.num_atoms = int(self._register_param(kwargs, "num_atoms", 51))
+        v_min = float(self._register_param(kwargs, "v_min", -10))
+        v_max = float(self._register_param(kwargs, "v_max", 10))
 
         # Reason sequence initiation.
-        self.gamma = float(self._register_param(kwargs, 'gamma', 0.99))
-        self.tau = float(self._register_param(kwargs, 'tau', 0.02))
-        self.batch_size = int(self._register_param(kwargs, 'batch_size', 64))
-        self.buffer_size = int(self._register_param(kwargs, 'buffer_size', int(1e6)))
+        self.gamma = float(self._register_param(kwargs, "gamma", 0.99))
+        self.tau = float(self._register_param(kwargs, "tau", 0.02))
+        self.batch_size = int(self._register_param(kwargs, "batch_size", 64))
+        self.buffer_size = int(self._register_param(kwargs, "buffer_size", int(1e6)))
         self.buffer = PERBuffer(self.batch_size, self.buffer_size)
 
         self.n_steps = int(self._register_param(kwargs, "n_steps", 3))
         self.n_buffer = NStepBuffer(n_steps=self.n_steps, gamma=self.gamma)
 
-        self.warm_up = int(self._register_param(kwargs, 'warm_up', 0))
-        self.update_freq = int(self._register_param(kwargs, 'update_freq', 1))
+        self.warm_up = int(self._register_param(kwargs, "warm_up", 0))
+        self.update_freq = int(self._register_param(kwargs, "update_freq", 1))
 
-        hidden_layers = to_numbers_seq(self._register_param(kwargs, 'hidden_layers', (128, 128)))
-        self.actor_hidden_layers = to_numbers_seq(self._register_param(kwargs, 'actor_hidden_layers', hidden_layers))
-        self.critic_hidden_layers = to_numbers_seq(self._register_param(kwargs, 'critic_hidden_layers', hidden_layers))
+        hidden_layers = to_numbers_seq(self._register_param(kwargs, "hidden_layers", (128, 128)))
+        self.actor_hidden_layers = to_numbers_seq(self._register_param(kwargs, "actor_hidden_layers", hidden_layers))
+        self.critic_hidden_layers = to_numbers_seq(self._register_param(kwargs, "critic_hidden_layers", hidden_layers))
 
         if kwargs.get("simple_policy", False):
             std_init = float(self._register_param(kwargs, "std_init", 1.0))
             std_max = float(self._register_param(kwargs, "std_max", 2.0))
             std_min = float(self._register_param(kwargs, "std_min", 0.05))
             self.policy = MultivariateGaussianPolicySimple(
-                action_size, std_init=std_init, std_min=std_min, std_max=std_max, device=self.device,
+                action_size,
+                std_init=std_init,
+                std_min=std_min,
+                std_max=std_max,
+                device=self.device,
             )
         else:
             self.policy = MultivariateGaussianPolicy(action_size, device=self.device)
 
         # This looks messy but it's not that bad. Actor, critic_net and Critic(critic_net). Then the same for `target_`.
         self.actor = ActorBody(
-            obs_space.shape, (self.policy.param_dim*action_size,), hidden_layers=self.actor_hidden_layers,
-            gate_out=torch.tanh, device=self.device
+            obs_space.shape,
+            (self.policy.param_dim * action_size,),
+            hidden_layers=self.actor_hidden_layers,
+            gate_out=torch.tanh,
+            device=self.device,
         )
         critic_net = CriticBody(
-            obs_space.shape, action_size, out_features=(self.num_atoms,),
-            hidden_layers=self.critic_hidden_layers, device=self.device
+            obs_space.shape,
+            action_size,
+            out_features=(self.num_atoms,),
+            hidden_layers=self.critic_hidden_layers,
+            device=self.device,
         )
         self.critic = CategoricalNet(
             num_atoms=self.num_atoms, v_min=v_min, v_max=v_max, net=critic_net, device=self.device
         )
 
         self.target_actor = ActorBody(
-            obs_space.shape, (self.policy.param_dim*action_size,), hidden_layers=self.actor_hidden_layers,
-            gate_out=torch.tanh, device=self.device
+            obs_space.shape,
+            (self.policy.param_dim * action_size,),
+            hidden_layers=self.actor_hidden_layers,
+            gate_out=torch.tanh,
+            device=self.device,
         )
         target_critic_net = CriticBody(
-            obs_space.shape, action_size, out_features=(self.num_atoms,),
-            hidden_layers=self.critic_hidden_layers, device=self.device
+            obs_space.shape,
+            action_size,
+            out_features=(self.num_atoms,),
+            hidden_layers=self.critic_hidden_layers,
+            device=self.device,
         )
         self.target_critic = CategoricalNet(
             num_atoms=self.num_atoms, v_min=v_min, v_max=v_max, net=target_critic_net, device=self.device
@@ -140,9 +157,9 @@ class D4PGAgent(AgentBase):
         hard_update(self.target_critic, self.critic)
 
         # Optimization sequence initiation.
-        self.actor_lr = float(self._register_param(kwargs, 'actor_lr', 3e-4))
-        self.critic_lr = float(self._register_param(kwargs, 'critic_lr', 3e-4))
-        self.value_loss_func = nn.BCELoss(reduction='none')
+        self.actor_lr = float(self._register_param(kwargs, "actor_lr", 3e-4))
+        self.critic_lr = float(self._register_param(kwargs, "critic_lr", 3e-4))
+        self.value_loss_func = nn.BCELoss(reduction="none")
 
         self.actor_params = list(self.actor.parameters()) + list(self.policy.parameters())
         self.actor_optimizer = Adam(self.actor_params, lr=self.actor_lr)
@@ -154,12 +171,12 @@ class D4PGAgent(AgentBase):
 
         # Breath, my child.
         self.iteration = 0
-        self._loss_actor = float('nan')
-        self._loss_critic = float('nan')
+        self._loss_actor = float("nan")
+        self._loss_critic = float("nan")
 
     @property
     def loss(self) -> Dict[str, float]:
-        return {'actor': self._loss_actor, 'critic': self._loss_critic}
+        return {"actor": self._loss_actor, "critic": self._loss_critic}
 
     @cached_property
     def action_min(self):
@@ -172,14 +189,14 @@ class D4PGAgent(AgentBase):
     @loss.setter
     def loss(self, value):
         if isinstance(value, dict):
-            self._loss_actor = value['actor']
-            self._loss_critic = value['critic']
+            self._loss_actor = value["actor"]
+            self._loss_critic = value["critic"]
         else:
             self._loss_actor = value
             self._loss_critic = value
 
     @torch.no_grad()
-    def act(self, obs: ObsType, epsilon: float=0.) -> List[float]:
+    def act(self, experience: Experience, epsilon: float = 0.0) -> Experience:
         """
         Returns actions for given observation as per current policy.
 
@@ -191,34 +208,31 @@ class D4PGAgent(AgentBase):
         actions = []
 
         obs_shape = (self.num_workers,) + self.obs_space.shape
-        t_obs = to_tensor(obs).view(obs_shape).float().to(self.device)
+        t_obs = to_tensor(experience.obs).view(obs_shape).float().to(self.device)
         for worker in range(self.num_workers):
             if self._rng.random() < epsilon:
                 r = torch.rand(self.action_space.shape) - 0.5
-                action = (self.action_max - self.action_min)*r - self.action_min
+                action = (self.action_max - self.action_min) * r - self.action_min
             else:
                 action_seed = self.actor.act(t_obs[worker].view(1, -1))
-                action_dist = self.policy(action_seed)
-                action = action_dist.sample()
+                action = self.policy(action_seed)
                 action = torch.clamp(action.squeeze(), self.action_min, self.action_max).cpu()
             actions.append(action.tolist())
 
         assert len(actions) == self.num_workers
-        return actions
+        experience.update(action=actions)
+        return experience
 
-    def step(
-        self, obss: List[ObsType], actions: List[ActionType], rewards: List[RewardType],
-        next_obss: List[ObsType], dones: List[DoneType],
-    ):
+    def step(self, experience: Experience):
         self.iteration += 1
 
         # Delay adding to buffer to account for n_steps (particularly the reward)
         self.n_buffer.add(
-            state=torch.tensor(obss).reshape((self.num_workers,) + self.obs_space.shape).float(),
-            next_state=torch.tensor(next_obss).reshape((self.num_workers,) + self.obs_space.shape).float(),
-            action=torch.tensor(actions).reshape((self.num_workers,) + self.action_space.shape).float(),
-            reward=torch.tensor(rewards).reshape(self.num_workers, 1),
-            done=torch.tensor(dones).reshape(self.num_workers, 1),
+            obs=torch.tensor(experience.obs).reshape((self.num_workers,) + self.obs_space.shape).float(),
+            next_obs=torch.tensor(experience.next_obs).reshape((self.num_workers,) + self.obs_space.shape).float(),
+            action=torch.tensor(experience.action).reshape((self.num_workers,) + self.action_space.shape).float(),
+            reward=torch.tensor(experience.reward).reshape(self.num_workers, 1),
+            done=torch.tensor(experience.done).reshape(self.num_workers, 1),
         )
         if not self.n_buffer.available:
             return
@@ -226,11 +240,11 @@ class D4PGAgent(AgentBase):
         samples = self.n_buffer.get().get_dict()
         for worker_idx in range(self.num_workers):
             self.buffer.add(
-                state=samples['state'][worker_idx],
-                next_state=samples['next_state'][worker_idx],
-                action=samples['action'][worker_idx],
-                done=samples['done'][worker_idx],
-                reward=samples['reward'][worker_idx],
+                obs=samples["obs"][worker_idx],
+                next_obs=samples["next_obs"][worker_idx],
+                action=samples["action"][worker_idx],
+                done=samples["done"][worker_idx],
+                reward=samples["reward"][worker_idx],
             )
 
         if self.iteration < self.warm_up:
@@ -248,7 +262,7 @@ class D4PGAgent(AgentBase):
 
         # Q_w' estimate via Bellman's dist operator
         next_action_seeds = self.target_actor.act(next_states)
-        next_actions = self.policy(next_action_seeds).sample()
+        next_actions = self.policy(next_action_seeds)
         assert next_actions.shape == (self.batch_size,) + self.action_space.shape
 
         target_value_dist_est = self.target_critic.act(states, next_actions)
@@ -256,7 +270,7 @@ class D4PGAgent(AgentBase):
         target_value_dist_est = target_value_dist_est.squeeze()
         assert target_value_dist_est.shape == (self.batch_size, self.num_atoms)
 
-        discount = self.gamma ** self.n_steps
+        discount = self.gamma**self.n_steps
         target_value_projected = self.target_critic.dist_projection(rewards, 1 - dones, discount, target_value_dist_est)
         assert target_value_projected.shape == (self.batch_size, self.num_atoms)
 
@@ -269,7 +283,7 @@ class D4PGAgent(AgentBase):
         samples_error = loss.sum(dim=-1).pow(2)
         loss_critic = samples_error.mean()
 
-        if hasattr(self.buffer, 'priority_update') and indices is not None:
+        if hasattr(self.buffer, "priority_update") and indices is not None:
             assert (~torch.isnan(samples_error)).any()
             self.buffer.priority_update(indices, samples_error.detach().cpu().numpy())
 
@@ -279,12 +293,12 @@ class D4PGAgent(AgentBase):
         # Compute actor loss
         pred_action_seeds = self.actor(states)
         pred_actions = self.policy.act(pred_action_seeds)
-        pred_actions = self.policy(pred_action_seeds).rsample()
+        pred_actions = self.policy(pred_action_seeds)
         # Negative because the optimizer minimizes, but we want to maximize the value
         value_dist = self.critic(states, pred_actions)
         self._batch_value_dist_metric = value_dist.detach()
         # Estimate on Z support
-        return -torch.mean(value_dist*self.critic.z_atoms)
+        return -torch.mean(value_dist * self.critic.z_atoms)
 
     def learn(self, experiences):
         """Update critics and actors"""
@@ -293,15 +307,15 @@ class D4PGAgent(AgentBase):
         batch_action_shape = (self.batch_size,) + self.action_space.shape
 
         # No need for size assertion since .view() has explicit sizes
-        rewards = to_tensor(experiences['reward']).view(self.batch_size, 1).float().to(self.device)
-        dones = to_tensor(experiences['done']).view(self.batch_size, 1).type(torch.int).to(self.device)
-        states = to_tensor(experiences['state']).view(batch_obs_shape).float().to(self.device)
-        actions = to_tensor(experiences['action']).view(batch_action_shape).to(self.device)
-        next_states = to_tensor(experiences['next_state']).view(batch_obs_shape).float().to(self.device)
+        rewards = to_tensor(experiences["reward"]).view(self.batch_size, 1).float().to(self.device)
+        dones = to_tensor(experiences["done"]).view(self.batch_size, 1).type(torch.int).to(self.device)
+        states = to_tensor(experiences["state"]).view(batch_obs_shape).float().to(self.device)
+        actions = to_tensor(experiences["action"]).view(batch_action_shape).to(self.device)
+        next_states = to_tensor(experiences["next_state"]).view(batch_obs_shape).float().to(self.device)
 
         indices = None
-        if hasattr(self.buffer, 'priority_update'):  # When using PER buffer
-            indices = experiences['index']
+        if hasattr(self.buffer, "priority_update"):  # When using PER buffer
+            indices = experiences["index"]
 
         # Value (critic) optimization
         loss_critic = self.compute_value_loss(states, actions, next_states, rewards, dones, indices)
@@ -334,7 +348,7 @@ class D4PGAgent(AgentBase):
             "actor": self.actor.state_dict(),
             "target_actor": self.target_actor.state_dict(),
             "critic": self.critic.state_dict(),
-            "target_critic": self.target_critic()
+            "target_critic": self.target_critic(),
         }
 
     def log_metrics(self, data_logger: DataLogger, step, full_log=False):
@@ -343,8 +357,8 @@ class D4PGAgent(AgentBase):
         policy_params = {str(i): v for i, v in enumerate(itertools.chain.from_iterable(self.policy.parameters()))}
         data_logger.log_values_dict("policy/param", policy_params, step)
 
-        data_logger.create_histogram('metric/batch_errors', self._metric_batch_error.sum(-1), step)
-        data_logger.create_histogram('metric/batch_value_dist', self._batch_value_dist_metric, step)
+        data_logger.create_histogram("metric/batch_errors", self._metric_batch_error.sum(-1), step)
+        data_logger.create_histogram("metric/batch_value_dist", self._batch_value_dist_metric, step)
 
         # This method, `log_metrics`, isn't executed on every iteration but just in case we delay plotting weights.
         # It simply might be quite costly. Thread wisely.
@@ -363,8 +377,10 @@ class D4PGAgent(AgentBase):
 
     def get_state(self):
         return dict(
-            actor=self.actor.state_dict(), target_actor=self.target_actor.state_dict(),
-            critic=self.critic.state_dict(), target_critic=self.target_critic.state_dict(),
+            actor=self.actor.state_dict(),
+            target_actor=self.target_actor.state_dict(),
+            critic=self.critic.state_dict(),
+            target_critic=self.target_critic.state_dict(),
             config=self._config,
         )
 
@@ -374,10 +390,10 @@ class D4PGAgent(AgentBase):
 
     def load_state(self, path: str):
         agent_state = torch.load(path)
-        self._config = agent_state.get('config', {})
+        self._config = agent_state.get("config", {})
         self.__dict__.update(**self._config)
 
-        self.actor.load_state_dict(agent_state['actor'])
-        self.critic.load_state_dict(agent_state['critic'])
-        self.target_actor.load_state_dict(agent_state['target_actor'])
-        self.target_critic.load_state_dict(agent_state['target_critic'])
+        self.actor.load_state_dict(agent_state["actor"])
+        self.critic.load_state_dict(agent_state["critic"])
+        self.target_actor.load_state_dict(agent_state["target_actor"])
+        self.target_critic.load_state_dict(agent_state["target_critic"])
