@@ -1,5 +1,7 @@
+import copy
 import itertools
-from typing import Dict, List, Tuple, Union
+from functools import cached_property
+from typing import Dict, Tuple, Union
 
 import numpy as np
 import torch
@@ -10,12 +12,14 @@ from ai_traineree import DEVICE
 from ai_traineree.agents import AgentBase
 from ai_traineree.agents.agent_utils import hard_update, soft_update
 from ai_traineree.buffers import PERBuffer
+from ai_traineree.buffers.buffer_factory import BufferFactory
 from ai_traineree.loggers import DataLogger
 from ai_traineree.networks.bodies import ActorBody, CriticBody
 from ai_traineree.networks.heads import DoubleCritic
 from ai_traineree.policies import GaussianPolicy, MultivariateGaussianPolicySimple
 from ai_traineree.types.dataspace import DataSpace
-from ai_traineree.types.primitive import ActionType, DoneType, ObsType, RewardType
+from ai_traineree.types.experience import Experience
+from ai_traineree.types.state import AgentState, BufferState, NetworkState
 from ai_traineree.utils import to_numbers_seq, to_tensor
 
 
@@ -28,6 +32,7 @@ class SACAgent(AgentBase):
     Based on
     "Soft Actor-Critic: Off-Policy Maximum Entropy Deep Reinforcement Learning with a Stochastic Actor"
     by Haarnoja et al. (2018) (http://arxiv.org/abs/1801.01290).
+
     """
 
     model = "SAC"
@@ -38,7 +43,7 @@ class SACAgent(AgentBase):
             obs_space (DataSpace): Dataspace describing the input.
             action_space (DataSpace): Dataspace describing the output.
 
-        Keyword parameters:
+        Keyword arguments:
             hidden_layers (tuple of ints): Shape of the hidden layers in fully connected network. Default: (128, 128).
             gamma (float):  Discount value. Default: 0.99.
             tau (float): Soft copy fraction. Default: 0.02.
@@ -58,49 +63,76 @@ class SACAgent(AgentBase):
 
         """
         super().__init__(**kwargs)
-        self.device = kwargs.get("device", DEVICE)
+        self.device = self._register_param(kwargs, "device", DEVICE, update=True)  # Default device is CUDA if available
         self.obs_space = obs_space
         self.action_space = action_space
-        self._config['obs_space'] = self.obs_space
-        self._config['action_space'] = self.action_space
+        self._config["obs_space"] = self.obs_space
+        self._config["action_space"] = self.action_space
         action_size = self.action_space.shape[0]  # Because of 1D
 
-        self.gamma: float = float(self._register_param(kwargs, 'gamma', 0.99))
-        self.tau: float = float(self._register_param(kwargs, 'tau', 0.02))
-        self.batch_size: int = int(self._register_param(kwargs, 'batch_size', 64))
-        self.buffer_size: int = int(self._register_param(kwargs, 'buffer_size', int(1e6)))
-        self.memory = PERBuffer(self.batch_size, self.buffer_size)
+        self.gamma: float = float(self._register_param(kwargs, "gamma", 0.99))
+        self.tau: float = float(self._register_param(kwargs, "tau", 0.02))
+        self.batch_size: int = int(self._register_param(kwargs, "batch_size", 64))
+        self.buffer_size: int = int(self._register_param(kwargs, "buffer_size", int(1e6)))
+        self.buffer = PERBuffer(self.batch_size, self.buffer_size)
 
-        self.action_min = self._register_param(kwargs, 'action_min', -1)
-        self.action_max = self._register_param(kwargs, 'action_max', 1)
-        self.action_scale = self._register_param(kwargs, 'action_scale', 1)
+        self.action_scale = self._register_param(kwargs, "action_scale", 1)
 
-        self.warm_up = int(self._register_param(kwargs, 'warm_up', 0))
-        self.update_freq = int(self._register_param(kwargs, 'update_freq', 1))
-        self.number_updates = int(self._register_param(kwargs, 'number_updates', 1))
-        self.actor_number_updates = int(self._register_param(kwargs, 'actor_number_updates', 1))
-        self.critic_number_updates = int(self._register_param(kwargs, 'critic_number_updates', 1))
+        self.warm_up = int(self._register_param(kwargs, "warm_up", 0))
+        self.update_freq = int(self._register_param(kwargs, "update_freq", 1))
+        self.number_updates = int(self._register_param(kwargs, "number_updates", 1))
+        self.critic_number_updates = int(self._register_param(kwargs, "critic_number_updates", 1))
+        self.actor_number_updates = int(self._register_param(kwargs, "actor_number_updates", 1))
 
         # Reason sequence initiation.
-        hidden_layers = to_numbers_seq(self._register_param(kwargs, 'hidden_layers', (128, 128)))
-        actor_hidden_layers = to_numbers_seq(self._register_param(kwargs, 'actor_hidden_layers', hidden_layers))
-        critic_hidden_layers = to_numbers_seq(self._register_param(kwargs, 'critic_hidden_layers', hidden_layers))
+        hidden_layers = to_numbers_seq(self._register_param(kwargs, "hidden_layers", (128, 128)))
+        actor_hidden_layers = to_numbers_seq(self._register_param(kwargs, "actor_hidden_layers", hidden_layers))
+        critic_hidden_layers = to_numbers_seq(self._register_param(kwargs, "critic_hidden_layers", hidden_layers))
 
-        self.simple_policy = bool(self._register_param(kwargs, "simple_policy", False))
+        self.simple_policy = bool(self._register_param(kwargs, "simple_policy", True))
         if self.simple_policy:
             self.policy = MultivariateGaussianPolicySimple(action_size, **kwargs)
             self.actor = ActorBody(
-                obs_space.shape, (self.policy.param_dim*action_size,), hidden_layers=actor_hidden_layers, device=self.device)
+                obs_space.shape,
+                (self.policy.param_dim * action_size,),
+                hidden_layers=actor_hidden_layers,
+                gate=nn.ReLU(),
+                gate_out=torch.tanh,
+                device=self.device,
+            )
         else:
             self.policy = GaussianPolicy(
-                (actor_hidden_layers[-1],), self.action_space.shape, out_scale=self.action_scale, device=self.device)
+                (actor_hidden_layers[-1],),
+                self.action_space.shape,
+                out_scale=self.action_scale,
+                gate=nn.ReLU(),
+                device=self.device,
+            )
             self.actor = ActorBody(
-                obs_space.shape, (actor_hidden_layers[-1],), hidden_layers=actor_hidden_layers[:-1], device=self.device)
+                obs_space.shape,
+                (actor_hidden_layers[-1],),
+                hidden_layers=actor_hidden_layers[:-1],
+                gate=nn.ReLU(),
+                gate_out=torch.tanh,
+                device=self.device,
+            )
 
         self.double_critic = DoubleCritic(
-            obs_space.shape, action_size, CriticBody, hidden_layers=critic_hidden_layers, device=self.device)
+            obs_space.shape,
+            action_size,
+            CriticBody,
+            hidden_layers=critic_hidden_layers,
+            gate=nn.ReLU(),
+            device=self.device,
+        )
         self.target_double_critic = DoubleCritic(
-            obs_space.shape, action_size, CriticBody, hidden_layers=critic_hidden_layers, device=self.device)
+            obs_space.shape,
+            action_size,
+            CriticBody,
+            hidden_layers=critic_hidden_layers,
+            gate=nn.ReLU(),
+            device=self.device,
+        )
 
         # Target sequence initiation
         hard_update(self.target_double_critic, self.double_critic)
@@ -112,8 +144,8 @@ class SACAgent(AgentBase):
         alpha_init = float(self._register_param(kwargs, "alpha", 0.2))
         self.log_alpha = torch.tensor(np.log(alpha_init), device=self.device, requires_grad=True)
 
-        actor_lr = float(self._register_param(kwargs, 'actor_lr', 3e-4))
-        critic_lr = float(self._register_param(kwargs, 'critic_lr', 3e-4))
+        actor_lr = float(self._register_param(kwargs, "actor_lr", 3e-4))
+        critic_lr = float(self._register_param(kwargs, "critic_lr", 3e-4))
 
         self.actor_params = list(self.actor.parameters()) + list(self.policy.parameters())
         self.critic_params = list(self.double_critic.parameters())
@@ -128,8 +160,8 @@ class SACAgent(AgentBase):
         # Breath, my child.
         self.iteration = 0
 
-        self._loss_actor = float('nan')
-        self._loss_critic = float('nan')
+        self._loss_actor = float("nan")
+        self._loss_critic = float("nan")
         self._metrics: Dict[str, Union[float, Dict[str, float]]] = {}
 
     @property
@@ -138,23 +170,40 @@ class SACAgent(AgentBase):
 
     @property
     def loss(self) -> Dict[str, float]:
-        return {'actor': self._loss_actor, 'critic': self._loss_critic}
+        return {"actor": self._loss_actor, "critic": self._loss_critic}
 
     @loss.setter
     def loss(self, value):
         if isinstance(value, dict):
-            self._loss_actor = value['actor']
-            self._loss_critic = value['critic']
+            self._loss_actor = value["actor"]
+            self._loss_critic = value["critic"]
         else:
             self._loss_actor = value
             self._loss_critic = value
 
+    def __eq__(self, o: object) -> bool:
+        return (
+            super().__eq__(o)
+            and isinstance(o, type(self))
+            and self._config == o._config
+            and self.buffer == o.buffer
+            and self.get_network_state() == o.get_network_state()  # TODO @dawid: Currently net isn't compared properly
+        )
+
     def reset_agent(self) -> None:
         self.actor.reset_parameters()
         self.policy.reset_parameters()
         self.double_critic.reset_parameters()
         hard_update(self.target_double_critic, self.double_critic)
 
+    @cached_property
+    def action_min(self):
+        return to_tensor(self.action_space.low)
+
+    @cached_property
+    def action_max(self):
+        return to_tensor(self.action_space.high)
+
     def state_dict(self) -> Dict[str, dict]:
         """
         Returns network's weights in order:
@@ -168,49 +217,67 @@ class SACAgent(AgentBase):
         }
 
     @torch.no_grad()
-    def act(self, obs: ObsType, epsilon: float=0.0, deterministic: bool=False) -> List[float]:
+    def act(self, experience: Experience, epsilon: float = 0.0, deterministic: bool = False) -> Experience:
         """Acting on the observations. Returns action.
 
         Parameters:
             obs (array_like): current state
             eps (float): epsilon, for epsilon-greedy action selection
-            deterministic (optional bool): Whether to use deterministic policy.
+            deterministic (optional bool): Whether to use deterministic policy. Only has effect in `train` mode.
+                In `test` mode all actions are deterministic.
 
         Returns:
             action: (list float) Action values.
 
         """
-        if self.iteration < self.warm_up or self._rng.random() < epsilon:
+        if self.train and self.iteration < self.warm_up or self._rng.random() < epsilon:
             rnd = torch.rand(self.action_space.shape)
             rnd_action = (self.action_max + self.action_min) * rnd + self.action_min
-            return rnd_action.cpu().tolist()
+            action = rnd_action.cpu().tolist()
+            return experience.update(action=action)
+
+        _deterministic = (not self.train) or deterministic
+        t_obs = to_tensor(experience.obs).view((1,) + self.obs_space.shape).float().to(self.device)
 
-        t_obs = to_tensor(obs).view((1,) + self.obs_space.shape).float().to(self.device)
         proto_action = self.actor(t_obs)
-        action = self.policy(proto_action, deterministic)
+        action = self.policy(proto_action, _deterministic).flatten()
+        if self.train and not deterministic:
+            last_samples = self.policy._last_samples
+            added_noise = action - self.policy(proto_action, deterministic=True).flatten()
+            noise_params = [*last_samples.get("mu").flatten().tolist(), *last_samples.get("std").flatten().tolist()]
+            experience = experience.update(noise=added_noise, noise_params=noise_params)
+        action = torch.clamp(action, self.action_min, self.action_max)
+        action = action.tolist()
+        return experience.update(action=action)
 
-        return action.flatten().tolist()
+    def step(self, experience: Experience) -> None:
+        if not self.train:
+            return
 
-    def step(self, obs: ObsType, action: ActionType, reward: RewardType, next_obs: ObsType, done: DoneType):
         self.iteration += 1
-        self.memory.add(
-            state=obs, action=action, reward=reward, next_state=next_obs, done=done,
+        self.buffer.add(
+            obs=experience.obs,
+            action=experience.action,
+            reward=experience.reward,
+            next_obs=experience.next_obs,
+            done=experience.done,
         )
 
         if self.iteration < self.warm_up:
             return
 
-        if len(self.memory) > self.batch_size and (self.iteration % self.update_freq) == 0:
+        if len(self.buffer) > self.batch_size and (self.iteration % self.update_freq) == 0:
             for _ in range(self.number_updates):
-                self.learn(self.memory.sample())
+                self.learn(self.buffer.sample())
 
     def compute_value_loss(self, states, actions, rewards, next_states, dones) -> Tuple[Tensor, Tensor]:
         Q1_expected, Q2_expected = self.double_critic(states, actions)
 
         with torch.no_grad():
-            proto_next_action = self.actor(states)
+            # next_actions, log_prob = self.actor(next_states)
+            proto_next_action = self.actor(next_states)
             next_actions = self.policy(proto_next_action)
-            log_prob = self.policy.logprob
+            log_prob = self.policy.log_prob(next_actions).view(-1, 1)
             assert next_actions.shape == (self.batch_size,) + self.action_space.shape
             assert log_prob.shape == (self.batch_size, 1)
 
@@ -227,80 +294,95 @@ class SACAgent(AgentBase):
         Q1_diff = Q1_expected - Q_target
         error_1 = Q1_diff.pow(2)
         mse_loss_1: Tensor = error_1.mean()
-        self._metrics['value/critic1'] = {'mean': float(Q1_expected.mean()), 'std': float(Q1_expected.std())}
-        self._metrics['value/critic1_lse'] = float(mse_loss_1.item())
+        self._metrics["value/critic1"] = {"mean": float(Q1_expected.mean()), "std": float(Q1_expected.std())}
+        self._metrics["value/critic1_lse"] = float(mse_loss_1.item())
 
         Q2_diff = Q2_expected - Q_target
         error_2 = Q2_diff.pow(2)
         mse_loss_2: Tensor = error_2.mean()
-        self._metrics['value/critic2'] = {'mean': float(Q2_expected.mean()), 'std': float(Q2_expected.std())}
-        self._metrics['value/critic2_lse'] = float(mse_loss_2.item())
+        self._metrics["value/critic2"] = {"mean": float(Q2_expected.mean()), "std": float(Q2_expected.std())}
+        self._metrics["value/critic2_lse"] = float(mse_loss_2.item())
 
-        Q_diff = Q1_expected - Q2_expected
-        self._metrics['value/Q_diff'] = {'mean': float(Q_diff.mean()), 'std': float(Q_diff.std())}
+        with torch.no_grad():
+            Q_diff = Q1_expected - Q2_expected
+            self._metrics["value/Q_diff"] = {"mean": float(Q_diff.mean()), "std": float(Q_diff.std())}
+            error: Tensor = torch.max(error_1, error_2)
 
-        error: Tensor = torch.min(error_1, error_2)
         loss = mse_loss_1 + mse_loss_2
         return loss, error
 
     def compute_policy_loss(self, states):
+        self.double_critic.requires_grad_ = False
         proto_actions = self.actor(states)
         pred_actions = self.policy(proto_actions)
-        log_prob = self.policy.logprob
+        log_prob = self.policy.log_prob(pred_actions)
         assert pred_actions.shape == (self.batch_size,) + self.action_space.shape
 
         Q_estimate = torch.min(*self.double_critic(states, pred_actions))
         assert Q_estimate.shape == (self.batch_size, 1)
 
-        self._metrics['policy/entropy'] = -float(log_prob.detach().mean())
+        self._metrics["policy/entropy"] = -float(log_prob.detach().mean())
         loss = (self.alpha * log_prob - Q_estimate).mean()
 
         # Update alpha
         if self.alpha_lr is not None:
             self.alpha_optimizer.zero_grad()
-            loss_alpha = -(self.alpha * (log_prob + self.target_entropy).detach()).mean()
+            # loss_alpha = -(self.alpha * (log_prob + self.target_entropy).detach()).mean()  # CORRECT?
+            loss_alpha = -(self.alpha * log_prob.detach()).mean()
             loss_alpha.backward()
             nn.utils.clip_grad_norm_(self.log_alpha, self.max_grad_norm_alpha)
             self.alpha_optimizer.step()
 
+        self.double_critic.requires_grad_ = True
         return loss
 
     def learn(self, samples):
-        """update the critics and actors of all the agents """
+        """update the critics and actors of all the agents"""
         batch_obs_shape = (self.batch_size,) + self.obs_space.shape
         batch_action_shape = (self.batch_size,) + self.action_space.shape
 
-        rewards = to_tensor(samples['reward']).float().to(self.device).view(self.batch_size, 1)
-        dones = to_tensor(samples['done']).int().to(self.device).view(self.batch_size, 1)
-        states = to_tensor(samples['state']).float().to(self.device).view(batch_obs_shape)
-        next_states = to_tensor(samples['next_state']).float().to(self.device).view(batch_obs_shape)
-        actions = to_tensor(samples['action']).to(self.device).view(batch_action_shape)
+        rewards = to_tensor(samples["reward"]).float().to(self.device).view(self.batch_size, 1)
+        dones = to_tensor(samples["done"]).int().to(self.device).view(self.batch_size, 1)
+        obss = to_tensor(samples["obs"]).float().to(self.device).view(batch_obs_shape)
+        next_obss = to_tensor(samples["next_obs"]).float().to(self.device).view(batch_obs_shape)
+        actions = to_tensor(samples["action"]).to(self.device).view(batch_action_shape)
+
+        self.actor_optimizer.zero_grad()
+        policy_loss = self.compute_policy_loss(obss)
+        policy_loss.backward()
+        nn.utils.clip_grad_norm_(self.actor_params, self.max_grad_norm_actor)
+        self.actor_optimizer.step()
 
         # Critic (value) update
-        for _ in range(self.critic_number_updates):
-            value_loss, error = self.compute_value_loss(states, actions, rewards, next_states, dones)
+        c_loss = np.zeros(self.critic_number_updates)
+        for idx in range(self.critic_number_updates):
             self.critic_optimizer.zero_grad()
+            value_loss, error = self.compute_value_loss(obss, actions, rewards, next_obss, dones)
             value_loss.backward()
-            nn.utils.clip_grad_norm_(self.critic_params, self.max_grad_norm_critic)
+            # nn.utils.clip_grad_norm_(self.critic_params, self.max_grad_norm_critic)
             self.critic_optimizer.step()
-            self._loss_critic = float(value_loss.item())
+            c_loss[idx] = float(value_loss.item())
+        self._loss_critic = c_loss.mean()
 
         # Actor (policy) update
-        for _ in range(self.actor_number_updates):
-            policy_loss = self.compute_policy_loss(states)
+        a_loss = np.zeros(self.actor_number_updates)
+        for idx in range(self.actor_number_updates):
             self.actor_optimizer.zero_grad()
+            policy_loss = self.compute_policy_loss(obss)
             policy_loss.backward()
-            nn.utils.clip_grad_norm_(self.actor_params, self.max_grad_norm_actor)
+            # nn.utils.clip_grad_norm_(self.actor_params, self.max_grad_norm_actor)
             self.actor_optimizer.step()
-            self._loss_actor = float(policy_loss.item())
+            a_loss[idx] = float(policy_loss.item())
 
-        if hasattr(self.memory, 'priority_update'):
+        self._loss_actor = a_loss.mean()
+
+        if hasattr(self.buffer, "priority_update"):
             assert any(~torch.isnan(error))
-            self.memory.priority_update(samples['index'], error.abs())
+            self.buffer.priority_update(samples["index"], error.abs())
 
         soft_update(self.target_double_critic, self.double_critic, self.tau)
 
-    def log_metrics(self, data_logger: DataLogger, step: int, full_log: bool=False):
+    def log_metrics(self, data_logger: DataLogger, step: int, full_log: bool = False):
         data_logger.log_value("loss/actor", self._loss_actor, step)
         data_logger.log_value("loss/critic", self._loss_critic, step)
         data_logger.log_value("loss/alpha", self.alpha, step)
@@ -335,25 +417,56 @@ class SACAgent(AgentBase):
                 if hasattr(layer, "bias") and layer.bias is not None:
                     data_logger.create_histogram(f"critic_2/layer_bias_{idx}", layer.bias, step)
 
-    def get_state(self):
-        return dict(
-            actor=self.actor.state_dict(),
-            policy=self.policy.state_dict(),
-            double_critic=self.double_critic.state_dict(),
-            target_double_critic=self.target_double_critic.state_dict(),
+    def get_state(self) -> AgentState:
+        return AgentState(
+            model=self.model,
+            obs_space=self.obs_space,
+            action_space=self.action_space,
+            buffer=copy.deepcopy(self.buffer.get_state()),
+            network=copy.deepcopy(self.get_network_state()),
             config=self._config,
         )
 
+    def get_network_state(self) -> NetworkState:
+        return NetworkState(
+            net=dict(
+                policy=self.policy.state_dict(),
+                actor=self.actor.state_dict(),
+                double_critic=self.double_critic.state_dict(),
+                target_double_critic=self.target_double_critic.state_dict(),
+            )
+        )
+
+    def set_buffer(self, buffer_state: BufferState) -> None:
+        self.buffer = BufferFactory.from_state(buffer_state)
+
+    def set_network(self, network_state: NetworkState) -> None:
+        self.policy.load_state_dict(network_state.net["policy"])
+        self.actor.load_state_dict(network_state.net["actor"])
+        self.double_critic.load_state_dict(network_state.net["double_critic"])
+        self.target_double_critic.load_state_dict(network_state.net["target_double_critic"])
+
+    @staticmethod
+    def from_state(state: AgentState) -> AgentBase:
+        config = copy.copy(state.config)
+        config.update({"obs_space": state.obs_space, "action_space": state.action_space})
+        agent = SACAgent(**config)
+        if state.network is not None:
+            agent.set_network(state.network)
+        if state.buffer is not None:
+            agent.set_buffer(state.buffer)
+        return agent
+
     def save_state(self, path: str):
         agent_state = self.get_state()
         torch.save(agent_state, path)
 
     def load_state(self, path: str):
         agent_state = torch.load(path)
-        self._config = agent_state.get('config', {})
+        self._config = agent_state.get("config", {})
         self.__dict__.update(**self._config)
 
-        self.actor.load_state_dict(agent_state['actor'])
-        self.policy.load_state_dict(agent_state['policy'])
-        self.double_critic.load_state_dict(agent_state['double_critic'])
-        self.target_double_critic.load_state_dict(agent_state['target_double_critic'])
+        self.actor.load_state_dict(agent_state["actor"])
+        self.policy.load_state_dict(agent_state["policy"])
+        self.double_critic.load_state_dict(agent_state["double_critic"])
+        self.target_double_critic.load_state_dict(agent_state["target_double_critic"])
