@@ -1,9 +1,12 @@
+from ai_traineree.buffers import BufferBase
+from ai_traineree.buffers.nstep import NStepBuffer
+from ai_traineree.buffers.per import PERBuffer
+from ai_traineree.buffers.replay import ReplayBuffer
+from ai_traineree.buffers.rollout import RolloutBuffer
 from ai_traineree.types import BufferState
-from ai_traineree.buffers import BufferBase, ReplayBuffer, PERBuffer, NStepBuffer, RolloutBuffer
 
 
 class BufferFactory:
-
     @staticmethod
     def from_state(state: BufferState) -> BufferBase:
         if state.type == ReplayBuffer.type:
